{ nixos-hardware, ... }:
{
  imports = [
    nixos-hardware.nixosModules.raspberry-pi-5
  ];

  boot = {
    kernelParams = [
      "8250.nr_uarts=11"
      "console=ttyAMA10,9600"
      "console=tty0"
    ];
    supportedFilesystems = [ "btrfs" ];
    initrd.systemd.enableTpm2 = false;
    loader.systemd-boot.enable = true;
    loader.efi.canTouchEfiVariables = false;
  };
  fileSystems = {
    "/" = {
      device = "none";
      fsType = "tmpfs";
      options = [
        "defaults"
        "size=2G"
        "mode=755"
        "noexec"
      ];
    };
    "/boot" = {
      device = "/dev/disk/by-uuid/F8BB-8019";
      fsType = "vfat";
    };
    "/nix" = {
      device = "/dev/disk/by-uuid/7741fa2e-ce5d-4aef-bf3c-8e283e973409";
      fsType = "btrfs";
      options = [
        "subvol=nix"
        "compress=zstd"
        "noatime"
      ];
      neededForBoot = true;
    };
    "/persist" = {
      device = "/dev/disk/by-uuid/7741fa2e-ce5d-4aef-bf3c-8e283e973409";
      fsType = "btrfs";
      options = [
        "subvol=persist"
        "compress=zstd"
        "noexec"
      ];
      neededForBoot = true;
    };
    "/snapshots" = {
      device = "/dev/disk/by-uuid/7741fa2e-ce5d-4aef-bf3c-8e283e973409";
      fsType = "btrfs";
      options = [
        "subvol=snapshots"
        "compress=zstd"
        "noexec"
      ];
      neededForBoot = false;
    };
    "/mnt/WD" = {
      device = "/dev/disk/by-uuid/EA2866C92866947B";
      fsType = "ntfs";
      options = [
        "nofail"
        "x-systemd.automount"
      ];
      neededForBoot = false;
    };
  };

  hardware = {
    bluetooth = {
      enable = true;
      powerOnBoot = true;
    };
  };

  powerManagement = {
    enable = true;
    cpuFreqGovernor = "powersave";
  };

  services = {
    upower.enable = true;
  };

  time.timeZone = "Europe/Berlin";
}
